@@ -9,7 +9,16 @@ def execute(next_process, handler, dependencies, **kwargs):
     fcn(*params, **kwargs)
     next_process(dependencies, **kwargs)
 
+
 class RouterMiddleware(Middleware):
     def set_up(self):
-        fcn, params = router.to_handler(self.handler.request.path, self.dependencies, **self.request_args)
-        fcn(*params, **self.request_args)
+        fcn, path_args = router.to_handler(self.handler.request.path, self.dependencies, **self.request_args)
+        self.dependencies['_fcn'] = fcn
+        self.dependencies['_path_args'] = path_args
+
+
+class ExecutionMiddleware(Middleware):
+    def set_up(self):
+        fcn = self.dependencies['_fcn']
+        path_args = self.dependencies['_path_args']
+        fcn(*path_args, **self.request_args)
\ No newline at end of file
